#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-8j0RbT9F6uWA7KfXc6CMTL
key:                  storable-tuple-0.1-8j0RbT9F6uWA7KfXc6CMTL
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  cda6b5dedbbb31528fa6c1b3374f2e19
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-8j0RbT9F6uWA7KfXc6CMTL
depends:
    base-4.18.2.1 base-orphans-0.9.3-LnxuvQm3cV53B6eMGFHVwF
    storable-record-0.0.7-3D4uBzy83WBGEPNfP7OUQn
    utility-ht-0.0.17.2-7RISOLfdqcc7CjOu8E2nnb

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

